@@ -312,6 +312,8 @@
 ( cd usr/man/man3 ; ln -sf CrtPhImgFmt.3.gz Tk_CreatePhotoImageFormat.3.gz )
 ( cd usr/man/man3 ; rm -rf Tk_QueueWindowEvent.3.gz )
 ( cd usr/man/man3 ; ln -sf QWinEvent.3.gz Tk_QueueWindowEvent.3.gz )
+( cd usr/man/man3 ; rm -rf Tk_AttachHWND.3.gz )
+( cd usr/man/man3 ; ln -sf GetHWND.3.gz Tk_AttachHWND.3.gz )
 ( cd usr/man/man3 ; rm -rf Tk_UnderlineTextLayout.3.gz )
 ( cd usr/man/man3 ; ln -sf TextLayout.3.gz Tk_UnderlineTextLayout.3.gz )
 ( cd usr/man/man3 ; rm -rf Tk_SetWindowBorder.3.gz )
